summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KMainWindow.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KMainWindow.java')
-rw-r--r--kdejava/koala/org/kde/koala/KMainWindow.java136
1 files changed, 68 insertions, 68 deletions
diff --git a/kdejava/koala/org/kde/koala/KMainWindow.java b/kdejava/koala/org/kde/koala/KMainWindow.java
index 1088910d..e11119bb 100644
--- a/kdejava/koala/org/kde/koala/KMainWindow.java
+++ b/kdejava/koala/org/kde/koala/KMainWindow.java
@@ -2,19 +2,19 @@
package org.kde.koala;
import org.kde.qt.Qt;
-import org.kde.qt.QDomDocument;
-import org.kde.qt.QMetaObject;
+import org.kde.qt.TQDomDocument;
+import org.kde.qt.TQMetaObject;
import org.kde.qt.QtSupport;
-import org.kde.qt.QCloseEvent;
-import org.kde.qt.QPixmap;
-import org.kde.qt.QPaintEvent;
-import org.kde.qt.QSize;
+import org.kde.qt.TQCloseEvent;
+import org.kde.qt.TQPixmap;
+import org.kde.qt.TQPaintEvent;
+import org.kde.qt.TQSize;
import java.util.ArrayList;
-import org.kde.qt.QWidget;
-import org.kde.qt.QDomElement;
-import org.kde.qt.QResizeEvent;
-import org.kde.qt.QChildEvent;
-import org.kde.qt.QMainWindow;
+import org.kde.qt.TQWidget;
+import org.kde.qt.TQDomElement;
+import org.kde.qt.TQResizeEvent;
+import org.kde.qt.TQChildEvent;
+import org.kde.qt.TQMainWindow;
/**
@@ -57,7 +57,7 @@ import org.kde.qt.QMainWindow;
@see KApplication
*/
-public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface, KXMLGUIClientInterface {
+public class KMainWindow extends TQMainWindow implements KXMLGUIBuilderInterface, KXMLGUIClientInterface {
protected KMainWindow(Class dummy){super((Class) null);}
/**
Flags that can be passed in an argument to the constructor to
@@ -81,7 +81,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
public static final int Save = 8;
public static final int Create = 16;
- public native QMetaObject metaObject();
+ public native TQMetaObject metaObject();
public native String className();
/**
Construct a main window.
@@ -111,21 +111,21 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
@short Construct a main window.
@see #http://doc#trolltech#com/3#2/qt#html#WidgetFlags-enum
*/
- public KMainWindow(QWidget parent, String name, int f) {
+ public KMainWindow(TQWidget parent, String name, int f) {
super((Class) null);
newKMainWindow(parent,name,f);
}
- private native void newKMainWindow(QWidget parent, String name, int f);
- public KMainWindow(QWidget parent, String name) {
+ private native void newKMainWindow(TQWidget parent, String name, int f);
+ public KMainWindow(TQWidget parent, String name) {
super((Class) null);
newKMainWindow(parent,name);
}
- private native void newKMainWindow(QWidget parent, String name);
- public KMainWindow(QWidget parent) {
+ private native void newKMainWindow(TQWidget parent, String name);
+ public KMainWindow(TQWidget parent) {
super((Class) null);
newKMainWindow(parent);
}
- private native void newKMainWindow(QWidget parent);
+ private native void newKMainWindow(TQWidget parent);
public KMainWindow() {
super((Class) null);
newKMainWindow();
@@ -135,21 +135,21 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
Overloaded constructor which allows passing some KMainWindow.CreationFlags.
@short Overloaded constructor which allows passing some KMainWindow.CreationFlags.
*/
- public KMainWindow(int cflags, QWidget parent, String name, int f) {
+ public KMainWindow(int cflags, TQWidget parent, String name, int f) {
super((Class) null);
newKMainWindow(cflags,parent,name,f);
}
- private native void newKMainWindow(int cflags, QWidget parent, String name, int f);
- public KMainWindow(int cflags, QWidget parent, String name) {
+ private native void newKMainWindow(int cflags, TQWidget parent, String name, int f);
+ public KMainWindow(int cflags, TQWidget parent, String name) {
super((Class) null);
newKMainWindow(cflags,parent,name);
}
- private native void newKMainWindow(int cflags, QWidget parent, String name);
- public KMainWindow(int cflags, QWidget parent) {
+ private native void newKMainWindow(int cflags, TQWidget parent, String name);
+ public KMainWindow(int cflags, TQWidget parent) {
super((Class) null);
newKMainWindow(cflags,parent);
}
- private native void newKMainWindow(int cflags, QWidget parent);
+ private native void newKMainWindow(int cflags, TQWidget parent);
public KMainWindow(int cflags) {
super((Class) null);
newKMainWindow(cflags);
@@ -202,13 +202,13 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
public native KPopupMenu customHelpMenu(boolean showWhatsThis);
public native KPopupMenu customHelpMenu();
/**
- Reimplementation of QMainWindow.show()
- @short Reimplementation of QMainWindow.show()
+ Reimplementation of TQMainWindow.show()
+ @short Reimplementation of TQMainWindow.show()
*/
public native void show();
/**
- Reimplementation of QMainWindow.hide()
- @short Reimplementation of QMainWindow.hide()
+ Reimplementation of TQMainWindow.hide()
+ @short Reimplementation of TQMainWindow.hide()
*/
public native void hide();
/**
@@ -236,7 +236,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
@param xmlfile The local xmlfile (relative or absolute)
@param _conserveMemory Specify whether createGUI() should call
KXMLGUIClient.conserveMemory() to free all memory
- allocated by the QDomDocument and by the KXMLGUIFactory.
+ allocated by the TQDomDocument and by the KXMLGUIFactory.
@short Create a GUI given a local XML file.
*/
public native void createGUI(String xmlfile, boolean _conserveMemory);
@@ -293,7 +293,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
@short
*/
- // QPtrListIterator<KToolBar> toolBarIterator(); >>>> NOT CONVERTED
+ // TQPtrListIterator<KToolBar> toolBarIterator(); >>>> NOT CONVERTED
/**
@return A KAccel instance bound to this mainwindow. Used automatically
by KAction to make keybindings work in all cases.
@@ -325,9 +325,9 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
- Put the setAutoSaveSettings ( or setupGUI() ) call after all widgets
have been created and placed inside the main window (i.e. for 99% of
apps setCentralWidget())
- - Widgets that inherit from QWidget (like game boards) should overload
- "QSize sizeHint() const;" to specify a default size rather
- than letting QWidget.adjust use the default size of 0x0.
+ - Widgets that inherit from TQWidget (like game boards) should overload
+ "TQSize sizeHint() const;" to specify a default size rather
+ than letting TQWidget.adjust use the default size of 0x0.
@short Call this to enable "auto-save" of toolbar/menubar/statusbar settings (and optionally window size).
*/
public native void setAutoSaveSettings(String groupName, boolean saveWindowSize);
@@ -432,9 +432,9 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
@short Configures the current windows and its actions in the typical KDE fashion.
@see StandardWindowOptions
*/
- public native void setupGUI(QSize defaultSize, int options, String xmlfile);
- public native void setupGUI(QSize defaultSize, int options);
- public native void setupGUI(QSize defaultSize);
+ public native void setupGUI(TQSize defaultSize, int options, String xmlfile);
+ public native void setupGUI(TQSize defaultSize, int options);
+ public native void setupGUI(TQSize defaultSize);
/**
Returns a pointer to the mainwindows action responsible for the toolbars menu
@short Returns a pointer to the mainwindows action responsible for the toolbars menu
@@ -464,7 +464,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
/**
@short
*/
- public native void setIcon(QPixmap arg1);
+ public native void setIcon(TQPixmap arg1);
/**
Show a standard configure toolbar dialog.
This slot can be connected dirrectly to the action to configure shortcuts.
@@ -512,7 +512,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
Example (adding a help button to the first toolbar):
<pre>
KIconLoader &loader = KGlobal.iconLoader();
- QPixmap pixmap = loader.loadIcon( "help" );
+ TQPixmap pixmap = loader.loadIcon( "help" );
toolBar(0).insertButton( pixmap, 0, SIGNAL("clicked()"),
this, SLOT("appHelpActivated()"), true, i18n("Help") );
</pre>
@@ -559,7 +559,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
// create default application as usual
}
</pre>
- Note that QWidget.show() is called implicitly in restore.
+ Note that TQWidget.show() is called implicitly in restore.
With this you can easily restore all toplevel windows of your
application.
If your application uses different kinds of toplevel
@@ -609,10 +609,10 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
List of members of KMainWindow class.
@short List of members of KMainWindow class.
*/
- // QPtrList<KMainWindow>* getMemberList(); >>>> NOT CONVERTED
- protected native void paintEvent(QPaintEvent e);
- protected native void childEvent(QChildEvent e);
- protected native void resizeEvent(QResizeEvent e);
+ // TQPtrList<KMainWindow>* getMemberList(); >>>> NOT CONVERTED
+ protected native void paintEvent(TQPaintEvent e);
+ protected native void childEvent(TQChildEvent e);
+ protected native void resizeEvent(TQResizeEvent e);
/**
Reimplemented to call the queryClose() and queryExit() handlers.
We recommend that you reimplement the handlers rather than closeEvent().
@@ -620,7 +620,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
queryExit() running.
@short Reimplemented to call the queryClose() and queryExit() handlers.
*/
- protected native void closeEvent(QCloseEvent arg1);
+ protected native void closeEvent(TQCloseEvent arg1);
/**
Called before the very last window is closed, either by the
user or indirectly by the session manager.
@@ -775,7 +775,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
saving.
Example:
<pre>
- void MyMainWindow.closeEvent( QCloseEvent e )
+ void MyMainWindow.closeEvent( TQCloseEvent e )
{
// Save settings if auto-save is enabled, and settings have changed
if ( settingsDirty() && autoSaveSettings() )
@@ -798,7 +798,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
public native void setBuilderClient(KXMLGUIClientInterface client);
public native KInstanceInterface builderInstance();
public native void setBuilderInstance(KInstanceInterface instance);
- public native QWidget widget();
+ public native TQWidget widget();
public native ArrayList containerTags();
/**
Creates a container (menubar/menu/toolbar/statusbar/separator/...)
@@ -812,16 +812,16 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
@param id The id to be used for this container
@short Creates a container (menubar/menu/toolbar/statusbar/separator/.
*/
- public native QWidget createContainer(QWidget parent, int index, QDomElement element, int[] id);
+ public native TQWidget createContainer(TQWidget parent, int index, TQDomElement element, int[] id);
/**
Removes the given (and previously via createContainer )
created container.
@short Removes the given (and previously via createContainer ) created container.
*/
- public native void removeContainer(QWidget container, QWidget parent, QDomElement element, int id);
+ public native void removeContainer(TQWidget container, TQWidget parent, TQDomElement element, int id);
public native ArrayList customTags();
- public native int createCustomElement(QWidget parent, int index, QDomElement element);
- public native void removeCustomElement(QWidget parent, int id);
+ public native int createCustomElement(TQWidget parent, int index, TQDomElement element);
+ public native void removeCustomElement(TQWidget parent, int id);
/**
Retrieves an action of the client by name. If not found, it looks in its child clients.
This method is provided for convenience, as it uses actionCollection()
@@ -830,21 +830,21 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
*/
public native KAction action(String name);
/**
- Retrieves an action for a given QDomElement. The default
+ Retrieves an action for a given TQDomElement. The default
implementation uses the "name" attribute to query the action
object via the other action() method.
- @short Retrieves an action for a given QDomElement.
+ @short Retrieves an action for a given TQDomElement.
*/
- public native KAction action(QDomElement element);
+ public native KAction action(TQDomElement element);
/**
Retrieves the entire action collection for the GUI client. If
you subclass KXMLGUIClient you should call
- KActionCollection.setWidget( QWidget ) with this object, or
+ KActionCollection.setWidget( TQWidget ) with this object, or
you will encounter subtle bugs with KAction keyboard shortcuts.
This is not necessary if your KXMLGUIClient is a KMainWindow.
@short Retrieves the entire action collection for the GUI client.
@see KActionCollection#setWidget(
- @see org.kde.qt.QWidget*
+ @see org.kde.qt.TQWidget*
*/
public native KActionCollection actionCollection();
/**
@@ -854,13 +854,13 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
*/
public native KInstanceInterface instance();
/**
- @return The parsed XML in a QDomDocument, set by
+ @return The parsed XML in a TQDomDocument, set by
setXMLFile() or setXML().
This document describes the layout of the GUI.
@short
*/
- public native QDomDocument domDocument();
+ public native TQDomDocument domDocument();
/**
This will return the name of the XML file as set by setXMLFile().
If setXML() is used directly, then this will return NULL.
@@ -879,11 +879,11 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
/**
@short
*/
- public native void setXMLGUIBuildDocument(QDomDocument doc);
+ public native void setXMLGUIBuildDocument(TQDomDocument doc);
/**
@short
*/
- public native QDomDocument xmlguiBuildDocument();
+ public native TQDomDocument xmlguiBuildDocument();
/**
This method is called by the KXMLGUIFactory as soon as the client
is added to the KXMLGUIFactory's GUI.
@@ -921,7 +921,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
Retrieves a list of all child clients.
@short Retrieves a list of all child clients.
*/
// const QPtrList<KXMLGUIClient>* childClients(); >>>> NOT CONVERTED
/**
A client can have an own KXMLGUIBuilder.
Use this method to assign your builder instance to the client (so that the
@@ -969,7 +969,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
This tag will get expanded to a list of actions. In the example
above ( a file manager with a dynamic file menu ), you would call
<pre>
- QPtrList<KAction> file_actions;
+ TQPtrList<KAction> file_actions;
for( ... )
if( ... )
file_actions.append( cool_action );
@@ -985,7 +985,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
menu too..
@short ActionLists are a way for XMLGUI to support dynamic lists of actions.
*/
// void plugActionList(const QString& arg1,const QPtrList<KAction>& arg2); >>>> NOT CONVERTED
/**
The complement of plugActionList() ...
@short The complement of plugActionList() .
@@ -993,10 +993,10 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
public native void unplugActionList(String name);
public native void addStateActionEnabled(String state, String action);
public native void addStateActionDisabled(String state, String action);
- // KXMLGUIClient::StateChange getActionsToChangeForState(const QString& arg1); >>>> NOT CONVERTED
- public native void beginXMLPlug(QWidget arg1);
+ // KXMLGUIClient::StateChange getActionsToChangeForState(const TQString& arg1); >>>> NOT CONVERTED
+ public native void beginXMLPlug(TQWidget arg1);
public native void endXMLPlug();
- public native void prepareXMLUnplug(QWidget arg1);
+ public native void prepareXMLUnplug(TQWidget arg1);
public static native String findMostRecentXMLFile(String[] files, StringBuffer doc);
/**
Sets the instance ( KInstance) for this part.
@@ -1035,8 +1035,8 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
setXMLFile or setXML .
@short Sets the Document for the part, describing the layout of the GUI.
*/
- protected native void setDOMDocument(QDomDocument document, boolean merge);
- protected native void setDOMDocument(QDomDocument document);
+ protected native void setDOMDocument(TQDomDocument document, boolean merge);
+ protected native void setDOMDocument(TQDomDocument document);
/**
This function will attempt to give up some memory after the GUI
is built. It should never be used in apps where the GUI may be
@@ -921,7 +921,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
*/
- // const QPtrList<KXMLGUIClient>* childClients(); >>>> NOT CONVERTED
+ // const TQPtrList<KXMLGUIClient>* childClients(); >>>> NOT CONVERTED
/**
A client can have an own KXMLGUIBuilder.
@@ -985,7 +985,7 @@ public class KMainWindow extends QMainWindow implements KXMLGUIBuilderInterface,
*/
- // void plugActionList(const QString& arg1,const QPtrList<KAction>& arg2); >>>> NOT CONVERTED
+ // void plugActionList(const TQString& arg1,const TQPtrList<KAction>& arg2); >>>> NOT CONVERTED
/**
The complement of plugActionList() ...